@@ -383,7 +383,7 @@ class MainWgt(QtGui.QMainWindow):
                 self.con_lost_lbl.hide()
                 self.con_lost_lbl.close()
             self.con_lost_lbl = ConnectLostLabel \
-                            (_('The Server was restarted.') + '\n' + \
+                            (_("The server was restarted.") + '\n' + \
                             _('Please try reconnecting to the server.'),
                             self, True)
             self.topmenu.Processes.setDisabled(True)
@@ -407,10 +407,10 @@ class MainWgt(QtGui.QMainWindow):
         if len(list_pid):
             if str(len(list_pid)).endswith('1'):
                 msgBox.setInformativeText(_('Once the session is closed, '\
-                    'data on %d process will be lost!') %len(list_pid))
+                    'data on process %d will be lost!') %len(list_pid))
             if len(list_pid) > 1:
                 msgBox.setInformativeText(_('Once the session is closed, '\
-                    'data on %d processes will be lost!') %len(list_pid))
+                    'data on process %d will be lost!') %len(list_pid))
 
         msgBox.setStandardButtons(QMessageBox.Yes | QMessageBox.No | \
                                   QMessageBox.Cancel)
@@ -464,4 +464,4 @@ class MainWgt(QtGui.QMainWindow):
         if e.key() == QtCore.Qt.Key_Return:
             self.control_button.keyPressEvent(e)
         else:
-            QtGui.QMainWindow.keyPressEvent(self, e)
\ No newline at end of file
+            QtGui.QMainWindow.keyPressEvent(self, e)
